CausalRelation

Enum CausalRelation 

pub enum CausalRelation {
    Equal,
    Before,
    After,
    Concurrent,
}
The causal relationship between two histories.

Variants



Equal

Both histories contain the same author sequences.



Before

The left history is strictly contained in the right history.



After

The left history strictly contains the right history.



Concurrent

Each history contains an event absent from the other.