SchemaActivation

Struct SchemaActivation 

pub struct SchemaActivation { /* private fields */ }
The atomic publication marker for a complete staged migration.

Implementations

Source

impl SchemaActivation

pub fn new( migration_id: MigrationId, from: SchemaDescriptor, to: SchemaDescriptor, staged_records: u64, staging_digest: BlobHash, ) -> Result<Self, MigrationCodecError>

Validates and constructs an activation marker.

pub const fn migration_id(&self) -> MigrationId

Returns the migration identifier.

pub const fn from(&self) -> &SchemaDescriptor

Returns the exact predecessor schema.

pub const fn to(&self) -> &SchemaDescriptor

Returns the exact target schema.

pub const fn staged_records(&self) -> u64

Returns the exact number of selected stage records.

pub const fn staging_digest(&self) -> BlobHash

Returns the digest committing to the complete ordered staging set.

pub fn encode_canonical(&self) -> Vec<u8>

Encodes the activation into its unique durable representation.

pub fn decode_canonical(bytes: &[u8]) -> Result<Self, MigrationCodecError>

Strictly decodes one canonical activation.