pub struct VersionVector { /* private fields */ }Expand description
A canonical summary of the highest observed commit sequence for each author.
Implementations
Sourceimpl VersionVector
impl VersionVector
Sourcepub fn covers(&self, dot: &Dot) -> bool
pub fn covers(&self, dot: &Dot) -> bool
Returns whether this history includes the commit containing dot.
Sourcepub fn relation(&self, other: &Self) -> CausalRelation
pub fn relation(&self, other: &Self) -> CausalRelation
Compares this history with another using vector-clock partial ordering.
Sourcepub fn iter(&self) -> impl ExactSizeIterator<Item = (&AuthorId, &u64)>
pub fn iter(&self) -> impl ExactSizeIterator<Item = (&AuthorId, &u64)>
Iterates over authors and sequences in canonical author order.